# Packages needed to run

- ccxt
- plotly
- pycoingecko
- pandas


# Command to install the required packages
## would recommend pairing this with a virtual environment

```
#option virtual env
#install
pip install virtual env

#creating
python3 -m virtualenv env

# activating
env\scripts\activate

# deactivating
env\scripts\deactivate


pip install -r requirements.text
```



# On the current free plan we can expect to retrieve one request per every 30 seconds


## further improvements can be made to increase the traffic if need bee
# testing changes

# showing jordan a test